@@ -8,7 +8,8 @@ from procmon_parser.consts import EventClass, ProcessOperation, RegistryOperatio
     FilesystemQueryInformationOperation, get_filesystem_access_mask_string, FilesystemDisposition, \
     get_filesysyem_create_options, get_filesysyem_create_attributes, get_filesysyem_create_share_mode, \
     FilesystemOpenResult, get_filesysyem_io_flags, FilesystemPriority, get_ioctl_name, FileInformationClass, \
-    get_filesysyem_notify_change_flags, FilesystemSetInformationOperation
+    get_filesystem_notify_change_flags, FilesystemSetInformationOperation, get_filesystem_createfilemapping_synctype, \
+    PageProtection
 from procmon_parser.stream_helper import read_u8, read_u16, read_u32, read_utf16, read_duration, \
     read_utf16_multisz, read_u64, read_filetime, read_s64
 
@@ -430,7 +431,7 @@ def get_filesystem_notify_change_directory_details(io, metadata, event, details_
     if metadata.sizeof_pvoid == 8:
         details_io.seek(4, 1)  # Padding for 64 bit
 
-    event.details["Filter"] = get_filesysyem_notify_change_flags(read_u32(details_io))
+    event.details["Filter"] = get_filesystem_notify_change_flags(read_u32(details_io))
 
 
 def get_filesystem_create_file_details(io, metadata, event, details_io, extra_detail_io):
@@ -480,6 +481,38 @@ def get_filesystem_create_file_details(io, metadata, event, details_io, extra_de
         event.category = "Write"
 
 
+def get_filesystem_create_file_mapping(io, metadata, event, details_io, extra_detail_io):
+    """Get detailed information about a FileSystem CreateFileMapping event.
+
+    Notes:
+         The CreateFileMapping event is basically the results of the IRP_MJ_ACQUIRE_FOR_SECTION_SYNCHRONIZATION IRP, but
+         without the FS_FILTER_SECTION_SYNC_OUTPUT output information. Only SyncType and PageProtection are available.
+         See: https://learn.microsoft.com/en-us/windows-hardware/drivers/ifs/flt-parameters-for-irp-mj-acquire-for-section-synchronization
+    """
+    # Only two fields are read from the details (there's also the detail string which is already read in the caller, see
+    # get_filesystem_event_details() function). Besides those, all other fields seem to be completely ignored.
+    details_io.seek(0x0C, 1)  # skip 0xC bytes from the beginning of details.
+    sync_type = read_u32(details_io)  # note: asm uses 'movsxd', so it's signed with sign extension.
+    page_protection = read_u32(details_io)
+    event.details["SyncType"] = get_filesystem_createfilemapping_synctype(sync_type)
+
+    if page_protection & PageProtection.PAGE_READONLY:
+        event.details["PageProtection"] = PageProtection.PAGE_READONLY.name
+    elif page_protection & PageProtection.PAGE_READWRITE:
+        event.details["PageProtection"] = PageProtection.PAGE_READWRITE.name
+    elif page_protection & PageProtection.PAGE_WRITECOPY:
+        event.details["PageProtection"] = PageProtection.PAGE_WRITECOPY.name
+    elif page_protection & PageProtection.PAGE_EXECUTE:
+        event.details["PageProtection"] = PageProtection.PAGE_EXECUTE.name
+    elif page_protection & PageProtection.PAGE_EXECUTE_READ:
+        event.details["PageProtection"] = PageProtection.PAGE_EXECUTE_READ.name
+    elif page_protection & PageProtection.PAGE_EXECUTE_READWRITE:
+        event.details["PageProtection"] = PageProtection.PAGE_EXECUTE_READWRITE.name
+
+    if page_protection & PageProtection.PAGE_NOCACHE and "PageProtection" in event.details:
+        event.details["PageProtection"] += "|PAGE_NOCACHE"
+
+
 def get_filesystem_read_write_file_details(io, metadata, event, details_io, extra_detail_io):
     event.category = "Read" if event.operation == "ReadFile" else "Write"
     details_io.seek(0x4, 1)
@@ -581,7 +614,9 @@ FilesystemSubOperationHandler = {
     FilesystemOperation.DeviceIoControl.name: get_filesystem_ioctl_details,
     FilesystemQueryInformationOperation.QueryIdInformation.name: get_filesystem_read_metadata_details,
     FilesystemQueryInformationOperation.QueryRemoteProtocolInformation.name: get_filesystem_read_metadata_details,
-    FilesystemSetInformationOperation.SetDispositionInformationFile.name: get_filesystem_setdispositioninformation_details,
+    FilesystemSetInformationOperation.SetDispositionInformationFile.name:
+        get_filesystem_setdispositioninformation_details,
+    FilesystemOperation.CreateFileMapping.name: get_filesystem_create_file_mapping,
 }
 
 
